import datetime

from django import template
from django.template.defaultfilters import date
from django.urls import reverse
from django.utils.safestring import mark_safe

from ..utils import ac_url

register = template.Library()


@register.simple_tag(takes_context=True)
def month_url(context, month, cls="", fmt="Y-m"):
    url_name, url_params = ac_url(
        "transaction_month", {"year": month.year, "month": month.month}, context
    )

    url = reverse(url_name, kwargs=url_params)
    return mark_safe(
        f"""<a class="{cls}" href="{url}"><time datetime="{date(month, "Y-m")}">"""
        f"""{date(month, fmt).capitalize()}</time></a>"""
    )


@register.simple_tag(takes_context=True)
def year_url(context, year, cls=""):
    if isinstance(year, datetime.date):
        year = year.year
    url_name, url_params = ac_url("transaction_year", {"year": year}, context)

    url = reverse(url_name, kwargs=url_params)
    return mark_safe(
        f"""<a class="{cls}" href="{url}">"""
        f"""<time datetime="{year}">{year}</time></a>"""
    )


@register.simple_tag(takes_context=True)
def tr_colspan(context):
    ncol = 10
    if context.get("category"):
        ncol -= 2
    if context.get("account"):
        ncol -= 2
    return ncol
